@@ -2,6 +2,7 @@
 #define __STAN__MATH__MATRIX_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
+#include <stan/math/matrix/accumulator.hpp>
 #include <stan/math/matrix/add.hpp>
 #include <stan/math/matrix/array_builder.hpp>
 #include <stan/math/matrix/assign.hpp>
@@ -42,6 +43,8 @@
 #include <stan/math/matrix/log.hpp>
 #include <stan/math/matrix/log_determinant.hpp>
 #include <stan/math/matrix/log_determinant_spd.hpp>
+#include <stan/math/matrix/log_softmax.hpp>
+#include <stan/math/matrix/log_sum_exp.hpp>
 #include <stan/math/matrix/max.hpp>
 #include <stan/math/matrix/mdivide_left.hpp>
 #include <stan/math/matrix/mdivide_left_tri.hpp>
